@@ -9,7 +9,8 @@
 
 const blockCommentRe = /\/\*[^]*?\*\//g;
 const lineCommentRe = /\/\/.*/g;
-const LOAD_MODULE_RE = /(?:^|[^.]\s*)(\bloadModule\s*?\(\s*?)([`'"])([^`'"]+)(\2\s*?\))/g;
+const LOAD_MODULE_RE =
+  /(?:^|[^.]\s*)(\bloadModule\s*?\(\s*?)([`'"])([^`'"]+)(\2\s*?\))/g;
 
 export function extract(code, filePath, defaultDependencyExtractor) {
   const dependencies = defaultDependencyExtractor(code);
